% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/swapdata-control.R
\name{swap_site_code}
\alias{swap_site_code}
\title{Generate site codes}
\usage{
swap_site_code(x, max_length = 4)
}
\arguments{
\item{x}{Character vector of site names.}

\item{max_length}{Numeric. Desired length of the generated codes. Must be
greater than 1. Default: \code{4}.}
}
\value{
A character vector of site codes derived from \code{x}.
}
\description{
Generates abbreviated site codes from their full names.
The codes follow a set pattern designed to be predictable and probably (but
not necessarily) unique.
}
\details{
\code{swap_site_code()} attempts to generate a fixed-width code consisting of the
abbreviation site name and, if present in the site name, a numeric suffix.
The pattern is determined by the value of the \code{max_length} parameter:
\itemize{
\item \code{max_length = 2}: \code{AB} or \code{A1}
\item \code{max_length = 3}: \code{ABC} or \code{AB1}
\item \code{max_length = 4}: \code{ABCD} or \code{AB01} (the default)
\item \code{max_length = 5}: \code{ABCDE} or \code{ABC01}
\item ...
}

A fixed-width output isn't guaranteed, for example if the name of the site
is shorter than \code{max_length}.

As long as they are preceded by a space, Roman numerals up to XXXIX (39) are
also recognised as a numeric suffix, and are converted to Arabic numbers.
}
\examples{
sites <- c("Çatalhöyük", "Chia Sabz", "Azraq 31", "Gilgal I", "Tell es-Sultan")
swap_site_code(sites)
}
